% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tests.R
\name{esgcortest}
\alias{esgcortest}
\title{Correlation test for shocks}
\usage{
esgcortest(
  x,
  alternative = c("two.sided", "less", "greater"),
  method = c("pearson", "kendall", "spearman"),
  conf.level = 0.95
)
}
\arguments{
\item{x}{A list containing two time series objects to test for correlation}

\item{alternative}{A character string specifying the alternative hypothesis:
"two.sided" (default), "less", or "greater"}

\item{method}{A character string indicating which correlation coefficient is to be used:
"pearson" (default), "kendall", or "spearman"}

\item{conf.level}{Confidence level for the returned confidence interval}
}
\value{
A list containing:
\itemize{
  \item cor.estimate: A time series of correlation estimates
  \item conf.int: A time series matrix containing the lower and upper bounds of the confidence intervals
}
}
\description{
Performs correlation tests between two sets of shocks at each time point.
}
\details{
The function performs correlation tests between two sets of shocks at each time point.
It returns both the correlation estimates and confidence intervals for the correlation
coefficient at each time point.
}
\examples{
# Generate sample shocks
x <- ts(matrix(rnorm(1000), 100, 10))
y <- ts(matrix(rnorm(1000), 100, 10))

# Test correlation between shocks
result <- esgcortest(list(x, y))

# Plot correlation estimates with confidence intervals
plot(result$cor.estimate)
lines(result$conf.int[,1], col="red")
lines(result$conf.int[,2], col="red")

}
