% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ycfwdrates.R
\name{esgfwdrates}
\alias{esgfwdrates}
\title{Instantaneous forward rates}
\usage{
esgfwdrates(
  in.maturities,
  in.zerorates,
  n,
  horizon,
  out.frequency = c("annual", "semi-annual", "quarterly", "monthly", "weekly", "daily"),
  method = c("fmm", "periodic", "natural", "monoH.FC", "hyman", "HCSPL", "SW"),
  ...
)
}
\arguments{
\item{in.maturities}{Vector of input maturities}

\item{in.zerorates}{Vector of input zero rates}

\item{n}{Number of simulations}

\item{horizon}{Time horizon for forward rates}

\item{out.frequency}{Output frequency for forward rates. One of:
\itemize{
  \item "annual" (default)
  \item "semi-annual"
  \item "quarterly" 
  \item "monthly"
  \item "weekly"
  \item "daily"
}}

\item{method}{Interpolation method. One of:
\itemize{
  \item "fmm" (default)
  \item "periodic"
  \item "natural"
  \item "monoH.FC"
  \item "hyman"
  \item "HCSPL"
  \item "SW"
}}

\item{...}{Additional arguments passed to interpolation functions}
}
\value{
A time series object containing the instantaneous forward rates
}
\description{
Computes instantaneous forward rates from zero rates using various interpolation methods.
}
\details{
The function computes instantaneous forward rates from zero rates using various interpolation methods.
It first converts zero rates to zero-coupon prices, then interpolates these prices using the specified method.
The forward rates are then computed from the interpolated prices.

The function supports different output frequencies and interpolation methods to suit various needs.
}
\examples{
# Generate sample data
maturities <- c(1, 2, 3, 5, 7, 10)
zero_rates <- c(0.01, 0.015, 0.02, 0.025, 0.03, 0.035)

# Compute forward rates with annual frequency
fwd_rates <- esgfwdrates(in.maturities = maturities,
                        in.zerorates = zero_rates,
                        n = 1000,
                        horizon = 10,
                        out.frequency = "annual",
                        method = "fmm")

}
