% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tests.R
\name{esgmartingaletest}
\alias{esgmartingaletest}
\title{Test for martingale property and market consistency}
\usage{
esgmartingaletest(
  r,
  X,
  p0,
  alpha = 0.05,
  method = c("onevsone", "trend", "ratio")
)
}
\arguments{
\item{r}{Risk-free rate (scalar or time series)}

\item{X}{Time series of asset prices or values}

\item{p0}{Initial price(s) for comparison}

\item{alpha}{Significance level for hypothesis tests (default: 0.05)}

\item{method}{Testing method:
\itemize{
  \item "onevsone": One-to-one comparison test
  \item "trend": Trend analysis test
  \item "ratio": Ratio-based test
}}
}
\value{
A list containing test results, which may include:
\itemize{
  \item t-statistic and p-value for ratio test
  \item trend analysis results
  \item mean and standard deviation of martingale differences
}
}
\description{
Performs statistical tests to verify if a time series follows a martingale property
and maintains market consistency. Three different testing methods are available.
}
\details{
The function implements three different approaches to test for martingale properties:
\itemize{
  \item "onevsone": Compares each observation against its expected value
  \item "trend": Analyzes trends in the martingale differences
  \item "ratio": Tests the ratio between discounted values and initial prices
}

The test results help determine if the time series maintains the martingale property
and market consistency under the risk-neutral measure.
}
\examples{
# Generate sample data
r <- 0.05
X <- ts(matrix(rnorm(1000), 100, 10), start = 0, deltat = 0.1)
p0 <- 100

# Perform martingale test using ratio method
result <- esgmartingaletest(r, X, p0, method = "ratio")

# Perform trend analysis
trend_result <- esgmartingaletest(r, X, p0, method = "trend")

}
