% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tests.R
\name{esgmccv}
\alias{esgmccv}
\title{Convergence of Monte Carlo prices}
\usage{
esgmccv(r, X, maturity, plot = TRUE, ...)
}
\arguments{
\item{r}{Interest rate time series or constant}

\item{X}{Price time series}

\item{maturity}{Maturity time point}

\item{plot}{Logical indicating whether to plot the convergence (default: TRUE)}

\item{...}{Additional arguments passed to plotting functions}
}
\value{
A list containing:
\itemize{
  \item avg.price: Vector of average prices for different numbers of simulations
  \item conf.int: Matrix of confidence intervals (lower and upper bounds)
}
}
\description{
Analyzes the convergence of Monte Carlo prices by computing average prices and confidence intervals
as the number of simulations increases.
}
\details{
The function computes the average price and confidence intervals for increasing numbers of simulations
to analyze the convergence of Monte Carlo estimates. It discounts the price series using the provided
interest rate and evaluates at the specified maturity.

If plot=TRUE, it creates a plot showing:
\itemize{
  \item Confidence intervals as shaded area
  \item Average price as a blue line
  \item X-axis showing number of simulations
  \item Y-axis showing Monte Carlo estimated prices
}
}
\examples{
# Generate sample data
r <- 0.05
X <- ts(matrix(rnorm(1000), 100, 10), start = 0, deltat = 0.1)

# Analyze convergence
convergence <- esgmccv(r, X, maturity = 1)

}
