% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulations_risks.R
\name{simdiff}
\alias{simdiff}
\title{Simulation of diffusion processes}
\usage{
simdiff(
  n,
  horizon,
  frequency = c("annual", "semi-annual", "quarterly", "monthly", "weekly", "daily"),
  model = c("GBM", "CIR", "OU"),
  x0,
  theta1 = NULL,
  theta2 = NULL,
  theta3 = NULL,
  lambda = NULL,
  mu_z = NULL,
  sigma_z = NULL,
  p = NULL,
  eta_up = NULL,
  eta_down = NULL,
  eps = NULL,
  start_ = NULL,
  end_ = NULL,
  seed = 123
)
}
\arguments{
\item{n}{Number of simulations/scenarios}

\item{horizon}{Time horizon for simulation}

\item{frequency}{Frequency of observations: if numeric (as for \code{ts} objects), 
better used with \code{start_} and \code{end_}. Otherwise a string, either "annual", 
"semi-annual", "quarterly", "monthly", "weekly", or "daily"}

\item{model}{Type of diffusion process: "GBM", "CIR", or "OU"}

\item{x0}{Initial value}

\item{theta1}{First parameter (drift for GBM, mean reversion for CIR/OU)}

\item{theta2}{Second parameter (volatility for GBM, long-term mean for CIR/OU)}

\item{theta3}{Third parameter (optional, used for some models)}

\item{lambda}{Jump intensity parameter (optional)}

\item{mu_z}{Mean of jump size (optional)}

\item{sigma_z}{Standard deviation of jump size (optional)}

\item{p}{Probability parameter (optional)}

\item{eta_up}{Upward jump size (optional)}

\item{eta_down}{Downward jump size (optional)}

\item{eps}{Pre-generated random shocks (optional)}

\item{start_}{Starting time (optional), better used with numeric \code{frequency}}

\item{end_}{Ending time (optional), better used with numeric \code{frequency}}

\item{seed}{Random seed for reproducibility}
}
\value{
A time series object containing the simulated paths
}
\description{
Simulates various diffusion processes including Geometric Brownian Motion (GBM), 
Cox-Ingersoll-Ross (CIR), and Ornstein-Uhlenbeck (OU) processes.
}
\details{
The function simulates various diffusion processes with different frequencies.
For GBM, theta1 represents the drift and theta2 the volatility.
For CIR and OU processes, theta1 is the mean reversion speed and theta2 is the long-term mean.
}
\examples{
# Simulate GBM process
eps <- simshocks(n = 10, horizon = 5, frequency = "quarterly")
sim_GBM <- simdiff(n = 10, horizon = 5, frequency = "quarterly",
                   model = "GBM", x0 = 100, theta1 = 0.03, theta2 = 0.1,
                   eps = eps)

# Simulate CIR process
sim_CIR <- simdiff(n = 10, horizon = 5, frequency = "quarterly",
                   model = "CIR", x0 = 0.04, theta1 = 1.5, theta2 = 0.04,
                   theta3 = 0.2, eps = eps)

}
