% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulations_shocks.R
\name{simshocks}
\alias{simshocks}
\title{Simulation of Gaussian shocks for risk factors}
\usage{
simshocks(
  n,
  horizon,
  frequency = c("annual", "semi-annual", "quarterly", "monthly", "weekly", "daily"),
  method = c("classic", "antithetic", "mm", "hybridantimm", "TAG"),
  family = NULL,
  par = NULL,
  par2 = rep(0, length(par)),
  RVM = NULL,
  type = c("CVine", "DVine", "RVine"),
  start_ = NULL,
  end_ = NULL,
  seed = 123
)
}
\arguments{
\item{n}{Number of simulations/scenarios}

\item{horizon}{Time horizon for simulation}

\item{frequency}{Frequency of observations: if numeric (as for \code{ts} objects), 
better used with \code{start_} and \code{end_}. Otherwise a string, either "annual", 
"semi-annual", "quarterly", "monthly", "weekly", or "daily"}

\item{method}{Simulation method: "classic", "antithetic", "mm" (moment matching),
"hybridantimm" (hybrid antithetic-moment matching), or "TAG"}

\item{family}{Vector of copula families (optional)}

\item{par}{Vector of copula parameters (optional)}

\item{par2}{Vector of second copula parameters (optional)}

\item{RVM}{RVineMatrix object for R-vine copula (optional)}

\item{type}{Type of vine copula: "CVine", "DVine", or "RVine"}

\item{start_}{Starting time (optional), better used with numeric \code{frequency}}

\item{end_}{Ending time (optional), better used with numeric \code{frequency}}

\item{seed}{Random seed for reproducibility}
}
\value{
A time series object containing the simulated Gaussian shocks
}
\description{
Generates Gaussian shocks for simulating risk factors using various methods including
classic Monte Carlo, antithetic variates, moment matching, and hybrid approaches.
}
\details{
The function generates Gaussian shocks that can be used for simulating various risk factors.
Different simulation methods are available:
\itemize{
  \item "classic": Standard Monte Carlo simulation
  \item "antithetic": Uses antithetic variates to reduce variance
  \item "mm": Moment matching to improve statistical properties
  \item "hybridantimm": Combines antithetic variates and moment matching
  \item "TAG": TAG method
}

When using copulas (by specifying family and par), the function supports C-vine, D-vine,
and R-vine copula structures.
}
\examples{
# Generate shocks using classic Monte Carlo
shocks <- simshocks(n = 1000, horizon = 5, frequency = "quarterly")

# Generate shocks using antithetic variates
shocks_antithetic <- simshocks(n = 1000, horizon = 5, frequency = "quarterly",
                              method = "antithetic")

# Generate shocks using C-vine copula
#shocks_copula <- simshocks(n = 1000, horizon = 5, frequency = "quarterly",
#                          family = c(1, 1), par = c(0.5, 0.3),
#                          type = "CVine")

}
